==> dasu_1.0.jar: edu/northwestern/dasu/stats/RSTStat.java <==
/**
 * News Project
 *
 * File:         DownloadStats.java
 * RCS:          $Id: RSTStat.java,v 1.2 2010/06/04 05:01:25 mas939 Exp $
 * Description:  DownloadStats class (see below)
 * Author:       David Choffnes
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 10, 2007 at 1:39:15 PM
 * Language:     Java
 * Package:      edu.northwestern.news.stats
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2007, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.stats;

import com.azureus.plugins.aznetmon.main.RSTPacketStats;

import edu.northwestern.dasu.util.Util;

/**
 * @author Mario Sanchez &lt;msanchez@u.northwestern.edu&gt;
 * 
 */


public class RSTStat implements Cloneable{
	
	public long timeRecorded;
	public long downloadId;
	public String peerIp;
	public int numRst = 1;
	public int type = 0;
	/* type 0: Connection Reset by Peer */
	/* type 1: forcibly removed by peer */
	public String bitTorrentClient;
	public int port;
	public String source;
	public boolean isSeed;
	public boolean amSeed;
	public int numSeeds;
	public int numPeers;
	

	public RSTStat() {
		timeRecorded = Util.currentGMTTime();
	}
	
	public RSTStat(long downloadId, String peerIp, long timeRecorded, int numRst) {

		this.timeRecorded = timeRecorded;
		this.downloadId = downloadId;
		this.peerIp = peerIp;
		this.numRst = numRst;

	}
	
	public RSTStat(long downloadId, String peerIp, long timeRecorded, int numRst, int type, 
			int port, String bitTorrentClient, String source, boolean isSeed, boolean amSeed,
			int numSeeds, int numPeers) {

		this.downloadId = downloadId;
		this.peerIp = peerIp;
		this.timeRecorded = timeRecorded; 
		this.numRst = numRst;
		this.type = type;
		this.bitTorrentClient = bitTorrentClient;
		this.port = port;
		this.source = source;
		this.isSeed = isSeed;
		this.amSeed = amSeed;
		this.numSeeds = numSeeds;
		this.numPeers = numPeers;

	}

	
     public Object clone() {

    	 try {
              return super.clone();
          }
    	 catch( CloneNotSupportedException e ) {
              return null;
          }
      } 
	
}

==> dasu_2.02.jar: edu/northwestern/dasu/stats/RSTStat.java <==
/**
 * Dasu Project
 *
 * File:         DownloadStats.java
 * RCS:          $Id: RSTStat.java,v 1.3 2010/10/22 19:51:35 mas939 Exp $
 * Description:  DownloadStats class (see below)
 * Author:       David Choffnes
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Apr 10, 2007 at 1:39:15 PM
 * Language:     Java
 * Package:      edu.northwestern.news.stats
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2007, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.stats;

import com.azureus.plugins.aznetmon.main.RSTPacketStats;

import edu.northwestern.dasu.util.Util;

/**
 * @author Mario Sanchez &lt;msanchez@u.northwestern.edu&gt;
 * 
 */


public class RSTStat implements Cloneable{
	
	public long timeRecorded;
	public long downloadId;
	public String peerIp;
	public int numRst = 1;
	public int type = 0;
	/* type 0: Connection Reset by Peer */
	/* type 1: forcibly removed by peer */
	public String bitTorrentClient;
	public int port;
	public String source;
	public boolean isSeed;
	public boolean amSeed;
	public int numSeeds;
	public int numPeers;
	public String encryption;
	

	public RSTStat() {
		timeRecorded = Util.currentGMTTime();
	}
	
	public RSTStat(long downloadId, String peerIp, long timeRecorded, int numRst) {

		this.timeRecorded = timeRecorded;
		this.downloadId = downloadId;
		this.peerIp = peerIp;
		this.numRst = numRst;

	}
	
	public RSTStat(long downloadId, String peerIp, long timeRecorded, int numRst, int type, 
			int port, String bitTorrentClient, String source, boolean isSeed, boolean amSeed,
			int numSeeds, int numPeers, String encryption) {

		this.downloadId = downloadId;
		this.peerIp = peerIp;
		this.timeRecorded = timeRecorded; 
		this.numRst = numRst;
		this.type = type;
		this.bitTorrentClient = bitTorrentClient;
		this.port = port;
		this.source = source;
		this.isSeed = isSeed;
		this.amSeed = amSeed;
		this.numSeeds = numSeeds;
		this.numPeers = numPeers;
		this.encryption = encryption;

	}

	
     public Object clone() {

    	 try {
              return super.clone();
          }
    	 catch( CloneNotSupportedException e ) {
              return null;
          }
      } 
	
}
